import { CompilerOptions } from 'typescript';
import { TypeScriptCompilerOptions } from '@teambit/typescript';
export type Target = 'ES3' | 'ES5' | 'ES2015' | 'ES2016' | 'ES2017' | 'ES2018' | 'ES2019' | 'ES2020' | 'ESNext';
export declare class TypescriptConfigMutator {
    raw: TypeScriptCompilerOptions;
    constructor(raw: TypeScriptCompilerOptions);
    clone(): TypescriptConfigMutator;
    setName(name: string): this;
    /**
     * optional. default to "dist".
     * useful when the build pipeline has multiple compiler tasks of the same compiler.
     * e.g. using the same Babel compiler for two different tasks, one for creating "es5" files, and
     * the second for creating "esm". the artifact names would be "es5" and "esm" accordingly.
     */
    setArtifactName(artifactName: string): this;
    /**
     * determines which ones of the generated files will be saved in the bit objects when tagging.
     * e.g. distGlobPatterns = [`${this.distDir}/**`, `!${this.distDir}/tsconfig.tsbuildinfo`];
     * see https://github.com/mrmlnc/fast-glob for the supported glob patters syntax.
     */
    setDistGlobPatterns(distGlobPatterns: string[]): this;
    /**
     * whether or not unsupported files (such as assets) should be copied into the dist directory
     */
    setShouldCopyNonSupportedFiles(shouldCopyNonSupportedFiles: boolean): this;
    /**
     * optional. default to "dist".
     * useful when the build pipeline has multiple compiler tasks of the same compiler.
     * e.g. using the same Babel compiler for two different tasks, one for creating "es5" files, and
     * the second for creating "esm". the artifact names would be "es5" and "esm" accordingly.
     */
    artifactName?: string;
    addTypes(typesPaths: string[]): TypescriptConfigMutator;
    setExperimentalDecorators(value: boolean): TypescriptConfigMutator;
    /**
     * Set ts compiler target option - https://www.typescriptlang.org/tsconfig#target
     */
    setTarget(target: Target): TypescriptConfigMutator;
    /**
     * Set ts compiler module option - https://www.typescriptlang.org/tsconfig#module
     */
    setModule(module: string): TypescriptConfigMutator;
    /**
     * This will change the dist dir for all relevant places:
     * 1. the dist dir of the compiler instance
     * 2. add exclude for the dist dir in the tsconfig
     * 3. set the outDir of the tsconfig
     * @param distDir
     * @returns
     */
    setDistDir(distDir: string): TypescriptConfigMutator;
    setOutDir(outDir: string): TypescriptConfigMutator;
    setCompilerOptions(options: CompilerOptions): TypescriptConfigMutator;
    setTsConfig(config: Record<string, any>): TypescriptConfigMutator;
    mergeTsConfig(config: Record<string, any>): TypescriptConfigMutator;
    addExclude(exclusions: string[]): TypescriptConfigMutator;
    /**
     * Run the compiler for .js files. this will only affect whether to run the compiler on the files
     * or not. It won't change the tsconfig to support or not support js files.
     */
    setCompileJs(compileJs: boolean): this;
    /**
     * Run the compiler for .js files. this will only affect whether to run the compiler on the files
     * or not. It won't change the tsconfig to support or not support jsx files.
     */
    setCompileJsx(compileJsx: boolean): this;
}
