"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypescriptConfigMutator = void 0;
const lodash_1 = require("lodash");
class TypescriptConfigMutator {
    constructor(raw) {
        this.raw = raw;
    }
    clone() {
        return new TypescriptConfigMutator((0, lodash_1.cloneDeep)(this.raw));
    }
    // TODO: move to a shared place, as all compilers mutators will need it
    setName(name) {
        this.raw.name = name;
        return this;
    }
    /**
     * optional. default to "dist".
     * useful when the build pipeline has multiple compiler tasks of the same compiler.
     * e.g. using the same Babel compiler for two different tasks, one for creating "es5" files, and
     * the second for creating "esm". the artifact names would be "es5" and "esm" accordingly.
     */
    setArtifactName(artifactName) {
        this.raw.artifactName = artifactName;
        return this;
    }
    // TODO: move to a shared place, as all compilers mutators will need it
    /**
     * determines which ones of the generated files will be saved in the bit objects when tagging.
     * e.g. distGlobPatterns = [`${this.distDir}/**`, `!${this.distDir}/tsconfig.tsbuildinfo`];
     * see https://github.com/mrmlnc/fast-glob for the supported glob patters syntax.
     */
    setDistGlobPatterns(distGlobPatterns) {
        this.raw.distGlobPatterns = distGlobPatterns;
        return this;
    }
    // TODO: move to a shared place, as all compilers mutators will need it
    /**
     * whether or not unsupported files (such as assets) should be copied into the dist directory
     */
    setShouldCopyNonSupportedFiles(shouldCopyNonSupportedFiles) {
        this.raw.shouldCopyNonSupportedFiles = shouldCopyNonSupportedFiles;
        return this;
    }
    addTypes(typesPaths) {
        this.raw.types.push(...typesPaths);
        return this;
    }
    setExperimentalDecorators(value) {
        this.raw.tsconfig.compilerOptions.experimentalDecorators = value;
        return this;
    }
    /**
     * Set ts compiler target option - https://www.typescriptlang.org/tsconfig#target
     */
    setTarget(target) {
        this.raw.tsconfig.compilerOptions.target = target;
        return this;
    }
    /**
     * Set ts compiler module option - https://www.typescriptlang.org/tsconfig#module
     */
    setModule(module) {
        this.raw.tsconfig.compilerOptions.module = module;
        return this;
    }
    /**
     * This will change the dist dir for all relevant places:
     * 1. the dist dir of the compiler instance
     * 2. add exclude for the dist dir in the tsconfig
     * 3. set the outDir of the tsconfig
     * @param distDir
     * @returns
     */
    setDistDir(distDir) {
        this.raw.distDir = distDir;
        this.addExclude([distDir]);
        this.setOutDir(distDir);
        return this;
    }
    setOutDir(outDir) {
        this.raw.tsconfig.compilerOptions.outDir = outDir;
        return this;
    }
    setCompilerOptions(options) {
        this.raw.tsconfig.compilerOptions = options;
        return this;
    }
    setTsConfig(config) {
        this.raw.tsconfig = config;
        return this;
    }
    mergeTsConfig(config) {
        this.raw.tsconfig = (0, lodash_1.merge)({}, this.raw.tsconfig, config);
        return this;
    }
    addExclude(exclusions) {
        this.raw.tsconfig.exclude.push(...exclusions);
        return this;
    }
    /**
     * Run the compiler for .js files. this will only affect whether to run the compiler on the files
     * or not. It won't change the tsconfig to support or not support js files.
     */
    setCompileJs(compileJs) {
        this.raw.compileJs = compileJs;
        return this;
    }
    /**
     * Run the compiler for .js files. this will only affect whether to run the compiler on the files
     * or not. It won't change the tsconfig to support or not support jsx files.
     */
    setCompileJsx(compileJsx) {
        this.raw.compileJsx = compileJsx;
        return this;
    }
}
exports.TypescriptConfigMutator = TypescriptConfigMutator;
//# sourceMappingURL=ts-config-mutator.js.map